/*  --------------------------------------------------------------------------------------
    Program  :  HdrWVblLABEL.sas

    Author   :  Perry Watts
    Date     :  30May2004 15:51

    Path     :  c:\N04\DDEwSASmac\SASAuto

    Purpose  :  Create the Text for a header line containing variable LABELS.

    Parms    :  Name             Description                                      Default
                ---------------  -----------------------------------------------  --------
                DSNAME           Data Set Name                                    NONE

    Notes    :  *Fixed Features:
                --None 
                *Implemented as a MACRO FUNCTION using SAS File I/O functions
                 with SYSFUNC.
                *Headers are defined as DATA. Therefore, they are associated 
                 with a DDE Triplet - not the Doublet.

    DDE Cmds :  None

    Example  :  filename HEADERS dde "excel|[&WkBook]sheet1!r3c1:r3c&nvar" notab;
                data _null_;
                . file HEADERS;
                . put %HdrWvblLabel(dsName=MyData)
                run;
    Copyright:  Copyright(C) 2004 Perry Watts
    -----------------------------------------------------------------------------------  */
 
  %macro HdrWVblLABEL(dsName=);
    %local rc nVars MaxLess1 i;
    %let rc=%sysfunc(open(&dsName));
    %let nVars = %sysfunc(attrn(&rc,NVARS));
    %let maxCol = %sysfunc(min(256,&nVars));   %*-- CONFORM TO SPREADSHEET LIMITS;
    %let MaxLess1=%eval(&maxCol - 1);
    %do i= 1 %to &MaxLess1; "%sysfunc(varLABEL(&rc,&i))" '09'x %end; "%sysfunc(varLABEL(&rc,&maxCol))";
    %let rc=%sysfunc(close(&rc));
  %mend HdrWVblLABEL;