/*  --------------------------------------------------------------------------------------
    Program  :  InsertLineDivider.sas

    Author   :  Perry Watts
    Date     :  30May2004 16:12

    Path     :  c:\N04\DDEwSASmac\SASAuto

    Purpose  :  Insert a thin colored line below the headers extending from 
                 column #1 to the number of columns in a data set. 

    Parms    :  Name             Description                                       Default
                ---------------  -----------------------------------------------   -------
                CMDFILENAME      DDE Doublet file name                             ddeCmds 
                SHEETNAME        Sheet Name                                        Sheet1
                COLOR            Background color.                                 15(gray)
                ROW              Row where line appears                            NONE
                MAXCOL           Max Column#                                       NONE

    Notes    :  *Fixed Features:
                --Line Height is set to 5 points. 
                *Invoke this macro at end of calling program after the
                 sheets have been loaded and formatted.

    DDE Cmds :  WORKBOOK.ACTIVATE(sheet_name)
                SELECT(selection, active_cell)
                INSERT(shift_num){shift_num ignored when whole row is being
                 inserted.}
                PATTERNS(apattern, afore, aback, newui)
                ROW.HEIGHT(height_num, reference, standard_height, type_num)

    Example  :  %insertLineDivider(row=4, sheetName=sheet1, maxCol=9)
    Copyright:  Copyright(C) 2004 Perry Watts
    -----------------------------------------------------------------------------------  */

  %macro insertLineDivider(cmdFileName=ddeCmds, sheetName=sheet1, color=15, row=, maxCol=);
    data _null_;
      file &cmdFileName;
      put %unquote(%bquote('[workbook.activate("&sheetName")]'));
      put %unquote(%bquote('[select("r&row")]'));
      put '[insert]';
      put %unquote(%bquote('[select("r&row.c1:r&row.c&maxCol")]'));
      put %unquote(%bquote('[patterns(1,0,&color.)]')); /* 0=NO FOREGROUND PATTERN*/                                        
      put %unquote(%bquote('[row.height(5,"r&row",false)]'));
    run;
  %mend insertLineDivider;