/*  --------------------------------------------------------------------------------------
    Program  :  OpenExcel.sas 

    Author   :  Perry Watts (copied from Christopher A. Roper "Intelligently Launching
                 Microsoft Excel from SAS, using SCL functions ported to Base SAS"
                 25p097.pdf).

    Date     :  28May2004 11:08

    Path     :  c:\N04\DDEwSASMac\SASAuto

    Purpose  :  Open EXCEL from inside SAS.

    Parms    :  Name             Description                                      Default
                ---------------  -----------------------------------------------  ---------------
                CMDFILENAME      DDE Doublet file name                            ddeCmds 

    Notes    :  *Fixed Features:
                --None
                *The macro can be re-invoked in a single session without altering
                 Excel. Once open, FID returns a value of 1.

    DDE Cmds :  None. Excel isn't opened yet.

    Example  :  %OpenExcel(cmdFileName=DDEdoublet)
    Copyright:  Copyright(C) 2004 Perry Watts
    -----------------------------------------------------------------------------------  */

    %macro OpenExcel(cmdfile=ddeCmds);
      data _null_;
       length fid rc start stop time 8;
       fid=fopen("&cmdFile",'s');  
       if (fid le 0) then do;
         rc=system('start excel');    *-- START IS A DOS COMMAND. 'SYSTEM' REPLACES 'X' CMD;
         start=datetime();
         stop=start+10;
         do while (fid le 0);         *-- NOT OPENED;
           fid=fopen("&cmdFile",'s'); *-- OPEN EXTERNAL FILE IN SEQUENTIAL INPUT MODE;
           time=datetime();
           if (time ge stop) then fid=1;
         end;
       end;
       rc=fclose(fid);                *-- CLOSING DDECMDS, NOT EXCEL;
      run;
    %mend OpenExcel;