/*  --------------------------------------------------------------------------------------
    Program  :  SaveANDClose.sas

    Author   :  Perry Watts
    Date     :  22Jun2004 09:49

    Path     :  c:\N04\DDEwSASMac\SASAuto

    Purpose  :  Allow a conditional EXCEL file SAVE and CLOSE based on the 
                parameter setting.

    Parms    :  Name             Description                                      Default
                ---------------  -----------------------------------------------  --------
                CMDFILENAME      DDE Doublet file name                             ddeCmds 
                YvsN             Toggles from Y to N                               Y(es)

    Notes    :  *Fixed Features
                --Automatic SAVE is attached to the CLOSE
                --EXCEL session is terminated
 
    DDE Cmds :  CLOSE()
                ERROR(enable_logical, macro_ref)
                QUIT()

    Examples :  %SaveANDClose; %SaveAndClose(YvsN=&YvsN); %SaveAndClose(YvsN=No);
    Copyright:  Copyright(C) 2004 Perry Watts
    -----------------------------------------------------------------------------------  */

    %macro SaveANDClose(cmdFileName=ddeCmds, YvsN=Y,);
      %if %upcase(%substr(&YvsN,1,1)) eq Y %then %do;
        data _null_;
          file &CmdFileName;
          put '[close(TRUE)]';  *-- SAVEs file and closes active window in EXCEL.;
          put '[error(false)]'; *-- Gets rid of dialog box;
          put '[quit()]';       *-- Close EXCEL;
        run;
      %end;
    %mend SaveANDClose;

       