/*  --------------------------------------------------------------------------------------
    Program  :  WriteDStoXLS.sas

    Author   :  Perry Watts
    Date     :  30May2004 16:36

    Path     :  c:\N04\DDEwSASmac\SASAuto

    Purpose  :  Create a customized PUT statement for writing a SAS data set out to
                 an EXCEL file.

    Parms    :  Name             Description                                      Default
                ---------------  -----------------------------------------------  --------
                DSNAME           Data Set Name                                    NONE

    Notes    :  *Fixed Features:
                --None 
                *Implemented as a MACRO FUNCTION using SAS File I/O functions
                 with SYSFUNC.
                *Data are associated with a DDE Triplet - not the Doublet.

    DDE Cmds :  None
 
    Example  :  filename ddedata dde "excel|[&WkBook]sheet1!r3c1:r3c&nvar" notab;  
                data _null_;
                .  set MySASds;
                .  file ddedata;
                .  put %WriteDStoXLS(dsName=MySASds)
                run;
    Copyright:  Copyright(C) 2004 Perry Watts
    -----------------------------------------------------------------------------------  */
  
  %macro WriteDStoXLS(dsName=);
    %local rc nVars MaxLess1 i;
    %let rc=%sysfunc(open(&dsName));
    %let nVars = %sysfunc(attrn(&rc,NVARS));
    %let MaxLess1=%eval(&nVars - 1);
    %do i= 1 %to &MaxLess1; %sysfunc(varname(&rc,&i)) +(-1) '09'x %end; %sysfunc(varname(&rc,&nVars));
    %let rc=%sysfunc(close(&rc));
  %mend WriteDStoXLS;