/*  --------------------------------------------------------------------------------------
    Program  :  AlignWorkSheet.sas

    Author   :  Perry Watts
    Date     :  27May2004 13:45

    Path     :  c:\N04\DDEwSASmac\SASAuto

    Purpose  :  Center adjust and auto-fit selected cells in a spreadsheet.

    Parms    :  Name             Description                                      Default
                ---------------  -----------------------------------------------  --------
                CMDFILENAME      DDE Doublet file name                            ddeCmds 
                SHEETNAME        Sheet Name                                       Sheet1
                MINROW           Min Row # (skip title(s), Use Header widths)     2
                MAXROW           Max Row #                                        NONE
                MINCOL           Min Column#                                      1
                MAXCOL           Max Column#                                      NONE

    Notes    :  *Fixed Features
                --Text is centered vertically and horizontally in a cell
                --Auto-fit height and width
                *Assume text has been written to the selected cells prior to
                 running this macro.

    DDE Cmds :  WORKBOOK.ACTIVATE(sheet_name)
                SELECT(selection, active_cell)
                ALIGNMENT(horiz_align, wrap, vert_align, orientation, add_indent)
                COLUMN.WIDTH(width_num, reference, standard, type_num, standard_num)
                ROW.HEIGHT(height_num, reference, standard_height, type_num)

    Example  :  %alignWorkSheet(Minrow=3, Maxrow=&EndRow, MaxCol=&EndCol)
    Copyright:  Copyright(C) 2004 Perry Watts
    -----------------------------------------------------------------------------------  */
 
  %macro AlignWorkSheet(cmdFileName=ddeCmds, sheetName=sheet1, minRow=2, maxRow=, minCol=1, maxCol=);
    data _null_;
      file &CmdFileName;
      put %unquote(%bquote('[workbook.activate("&sheetName")]'));
      put %unquote(%bquote('[select("r&minRow.c&minCol.:r&maxRow.c&maxCol")]'));
      put '[alignment(3,,2)]';                                                 *-- CENTER VERTICALLY AND HORIZONTALLY;
      put %unquote(%bquote('[column.width(0,"c&minCol.:c&maxCol",false,3)]')); *-- AUTO FIT COLUMN WIDTH;
      put %unquote(%bquote('[row.height(0,"r&minRow.:r&maxRow",false,3)]'));   *-- AUTO FIT ROW HEIGHT;
    run;
  %mend AlignWorkSheet;