/*  ---------------------------------------------------------------------------------------
    Program  :  formatBody.sas

    Author   :  Perry Watts
    Date     :  23Feb2004 18:50

    Path     :  c:\N04\DDEwSASmac\SASAuto

    Purpose  :  Format body text in a spreadsheet.

    Parms    :  Name             Description                                       Default
                ---------------  -----------------------------------------------   -------
                CMDFILENAME      DDE Doublet file name                             ddeCmds 
                FONTSIZE         Font Size                                         9 points
                SHEETNAME        Sheet Name                                        Sheet1
                MINROW           Min Row # (leave room for title and headers)      3
                MAXROW           Max Row #                                         NONE
                MINCOL           Min Column#                                       1
                MAXCOL           Max Column#                                       NONE

    Notes    :  *Fixed Features:
                --Font: Verdana with bold, italic, underline, strike, 
                   outline, shadow set to FALSE
                --Color: Black
                --Alignment: Centered vertically and horizontally
                --Auto Fit to column width and height

    DDE Cmds :  WORKBOOK.ACTIVATE(sheet_name)
                SELECT(selection, active_cell)
                FORMAT.FONT(name_text, size_num, bold, italic, underline, strike, color,
                            outline, shadow)
                ALIGNMENT(horiz_align, wrap, vert_align, orientation, add_indent)
                COLUMN.WIDTH(width_num, reference, standard, type_num, standard_num)
                ROW.HEIGHT(height_num, reference, standard_height, type_num)

    Example  :  %formatBody(fontsize=10, SheetName=sheet5, Maxrow=&EndRow, MaxCol=&EndCol)
    Copyright:  Copyright(C) 2004 Perry Watts
    ------------------------------------------------------------------------------------  */

   
  %macro formatBody(cmdFileName=ddeCmds, fontSize=9, sheetName=sheet1, minRow=3, maxRow=, minCol=1, maxCol=);
    data _null_;
      file &CmdFileName;
      put %unquote(%bquote('[workbook.activate("&sheetName")]'));
      put %unquote(%bquote('[select("r&minRow.c&MinCol.:r&maxRow.c&maxCol")]'));
      put %unquote(%bquote('[format.font("Verdana",&fontSize.,FALSE,false,false,false,1,false,false)]'));
      put '[alignment(3,,2)]';                   *-- CENTER VERTICALLY AND HORIZONTALLY;
      put %unquote(%bquote('[column.width(0,"c&minCol.:c&maxCol",false,3)]')); *-- AUTO FIT COLUMN WIDTH;
      put %unquote(%bquote('[row.height(0,"r&minRow.:r&maxRow",false,3)]'));   *-- AUTO FIT ROW HEIGHT;
    run;
  %mend formatBody;