/*  --------------------------------------------------------------------------------------
    Program  :  formatHeaders.sas 

    Author   :  Perry Watts
    Date     :  28May2004 11:08

    Path     :  c:\XLSBBU\SASAuto

    Purpose  :  Format Row Headers in a spreadsheet by defining font size, justification,
                 color, and column width.

    Parms    :  Name             Description                                      Default
                ---------------  -----------------------------------------------  ---------------
                CMDFILENAME      DDE Doublet file name                            ddeCmds 
                FONTSIZE         Font Size                                        9 points
                SHEETNAME        Sheet Name                                       Sheet1
                ITALIC           Italic switch                                    TRUE
                JUSTIFY          Justification                                    CENTER
                COLOR            Color                                            1 (Black)
                ROW              Header Row Number                                2
                MINCOL           Min Column#                                      1
                MAXCOL           Max Column#                                      NONE
                COLUMNWIDTH      Column Width                                     AUTO (fit text)

    Notes    :  *Fixed Features:
                --Font: Bold Verdana with underline, strike, outline and shadow set
                   to FALSE 
                --Alignment: Center vertically AND center OR left justify horizontally
                *Row Headers follow the title(s)
                *Execute prior to running macro alignWorkSheet

    DDE Cmds :  WORKBOOK.ACTIVATE(sheet_name)
                SELECT(selection, active_cell)
                FORMAT.FONT(name_text, size_num, bold, italic, underline, strike, color,
                 outline, shadow)
                ALIGNMENT(horiz_align, wrap, vert_align, orientation, add_indent)
                ROW.HEIGHT(height_num, reference, standard_height, type_num)
                COLUMN.WIDTH(width_num, reference, standard, type_num, standard_num)

    Example  :  %formatHeaders(Italic=FALSE, Color=5, Row=4, SheetName=sheet4,
                 MaxCol=5, ColumnWidth=50)
    Copyright:  Copyright(C) 2004 Perry Watts
    -----------------------------------------------------------------------------------  */

  %macro formatHeaders(cmdFileName=ddeCmds, fontSize=9, sheetName=sheet1, italic=TRUE,
                       justify=CENTER, color=1, row=2, minCol=1, maxCol=, columnWidth=AUTO);
    data _null_;
      file &CmdFileName;
      put %unquote(%bquote('[workbook.activate("&sheetName")]'));
      put %unquote(%bquote('[select("r&row.c&minCol.:r&row.c&maxCol")]'));
      put %unquote(%bquote('[format.font("Verdana",&fontSize.,TRUE,&Italic.,false,false,&color.,false,false)]'));
      %if %upcase(&justify) eq CENTER %then %do;
         put '[alignment(3,,2)]';  *-- CENTER VERTICALLY AND HORIZONTALLY;
      %end;
      %else %do;
         put '[alignment(2,,2)]';  *-- CENTER VERTICALLY AND LEFT-Justify HORIZONTALLY;
      %end;
      put %unquote(%bquote('[row.height(0,"r&row",true,3)]'));           
      %if %upcase(&ColumnWidth) eq AUTO %then %do;
        put %unquote(%bquote('[column.width(0,"c&minCol.:c&maxCol",true,3)]'));   
      %end;
      %else %do;
        put %unquote(%bquote('[column.width(&columnWidth,"c&minCol.:c&maxCol",FALSE)]'));
      %end;
    run;
  %mend formatHeaders;