/*  --------------------------------------------------------------------------------------
    Program  :  formatNumber.sas

    Author   :  Perry Watts
    Date     :  30May2004 14:53

    Path     :  c:\N04\DDEwSASmac\SASAuto

    Purpose  :  Format Numbers in a column with a "custom" EXCEL format.

    Parms    :  Name             Description                                       Default
                ---------------  -----------------------------------------------   -------
                CMDFILENAME      DDE Doublet file name                             ddeCmds 
                SHEETNAME        Sheet Name                                        Sheet1
                FMT              A "custom" EXCEL format                           NONE
                MINCOL           Min Column#                                       NONE
                MAXCOL           Max Column#                                       NONE

    Notes    :  *Fixed Features
                --Only one numeric format is permitted per column.
                *For FMT choices - follow EXCEL menus [format][Cells][Number]
                  [Custom]. Look at [Type] box.
                *EXCEL will skip over text in a column to format just the numerics.
                *Do not use this macro to format both zero-filled numbers and
                 dates in the same column.
 
    DDE Cmds :  WORKBOOK.ACTIVATE(sheet_name)
                SELECT(selection, active_cell)
                FORMAT.NUMBER(format_text)

    Example  :  %formatNumber(fmt=%str(000), sheetName=Sheet4, minCol=c1, maxCol=c1)
    Copyright:  Copyright(C) 2004 Perry Watts
    -----------------------------------------------------------------------------------  */

   %macro formatNumber(CmdFileName=ddeCmds, sheetName=sheet1, fmt=, minCol=, maxCol=);
    data _null_;
      file &CmdFileName;
      put %unquote(%bquote('[workbook.activate("&sheetName")]'));
      put %unquote(%bquote('[select("&minCol:&maxCol")]'));
      put %unquote(%bquote('[format.number("&fmt.")]'));  
      put '[select("r1c1")]';
     run;
  %mend formatNumber;
