/*  --------------------------------------------------------------------------------------
    Program  :  formatTitle.sas

    Author   :  Perry Watts
    Date     :  30May2004 15:10

    Path     :  c:\N04\DDEwSASmac\SASAuto

    Purpose  :  Format a spreadsheet title in black Verdana and center it across a
                 selection of multiple columns.

    Parms    :  Name             Description                                      Default
                ---------------  -----------------------------------------------  --------
                CMDFILENAME      DDE Doublet file name                             ddeCmds 
                FONTSIZE         Font Size                                         11 points
                SHEETNAME        Sheet Name                                        Sheet1
                ROWHEIGHT        Row Height                                        20 points
                ROW              Title Row Number                                  1
                MINCOL           Min Column# (Spanning Start Column)               1
                MAXCOL           Max Column# (Spanning End Column)                 NONE
 
    Notes    :  *Fixed Features:
                --Font: Bold Verdana with italic, underline, strike, 
                   outline, and shadow set to FALSE.
                --Color: Black
                --Alignment: Horizontally centered across selection spanning
                   multiple cells. Vertically centered.

    DDE Cmds :  WORKBOOK.ACTIVATE(sheet_name)
                SELECT(selection, active_cell)
                FORMAT.FONT(name_text, size_num, bold, italic, underline, strike, color,
                            outline, shadow)
                ALIGNMENT(horiz_align, wrap, vert_align, orientation, add_indent)
                ROW.HEIGHT(height_num, reference, standard_height, type_num)

    Example  :  %formatTitle(fontSize=12, RowHeight=15, SheetName=sheet4, maxCol=5)
    Copyright:  Copyright(C) 2004 Perry Watts
    -----------------------------------------------------------------------------------  */

  %macro formatTitle(cmdFileName=ddeCmds, fontSize=11, sheetName=sheet1, rowHeight=20, row=1, minCol=1, maxCol=);
    data _null_;
      file &CmdFileName;
      put %unquote(%bquote('[workbook.activate("&sheetName")]'));
      put %unquote(%bquote('[select("r&row.c&minCol.:r&row.c&maxCol")]'));
      put %unquote(%bquote('[format.font("Verdana",&fontSize.,TRUE,false,false,false,1,false,false)]'));
      put '[alignment(7)]';          *-- 7=CENTER ACROSS SELECTION;
      put '[alignment(,,2)]';        *-- VERTICALLY CENTERED;
      put %unquote(%bquote('[row.height(&rowHeight.,"r&row",false)]'));  *-- FIX ROW HEIGHT IN POINTS;
    run;
  %mend formatTitle;

