/*  ---------------------------------------------------------------------------
    Program  :  NESUGCallingPgm.sas

    Author   :  Perry Watts
    Date     :  21Jun2004 13:40

    Project  :  N04: DDEwSASMac
    Path     :  c:\N04\DDEwSASMac\pgm

    Purpose  :  Format a slightly modified version of sashelp.Class Data Set
                by calling single-purpose SAS macros stored in a SASAUTO library.
                 
    Input    :  sashelp.class

    Output   :  SASHelpClass.xls
    Copyright:  Copyright(C) 2004 Perry Watts
    ------------------------------------------------------------------------  */  

	   options mprint mautosource;
    options sasautos=(sasautos 'c:\N04\DDEwSASMac\sasauto');
    options nodate number pageno=1 source2;
	   options noxsync noxwait;
    options missing=' ';
 
    Footnote1;
    title1;

    %let doit=Yes;      *-- FOR FINAL SAVE AND CLOSE AT END;
 
    %let rowOffset=3;  *-- ACCOMMODATES ONE TITLE AND TWO LINES OF HEADERS;

    /* GET #ROWS, #COLUMNS FROM SCL FUNCTIONS*/
    %let rc=%sysfunc(open(sashelp.class));
      %let nVars = %left(%sysfunc(attrn(&rc,NVARS)));
      %let nobs = %sysfunc(attrn(&rc,NOBS));
      %let nrows=%eval(&nobs + &rowOffset);
      %let startRow=%eval(&rowOffset +1);
    %let rc=%sysfunc(close(&rc.));

    /* SEARCH EXCEL HELP FOR WORKSHEET SIZE */
    %let XLSmaxRow=65536;
    %let XLSmaxCol=256;

    /* TO ISSUE X4ML (EXCEL-VSN4-MACRO LANGUAGE) COMMANDS */
    filename ddeCMDS dde 'excel|system';

    /* ASSIGN VARIABLE LABELS TO SASHELP.CLASS*/    
    data class;
      set sashelp.class;
      label Name='First Name'
            Sex='Sex'
            Age='Age'
            Height='Height (inches)'
            Weight='Weight (pounds)';          
    run;

    proc print data=class label;
     title1 "SASHelp.Class to be Formatted in EXCEL with SAS Macros";
    run cancel;

    %OpenExcel;

  /* SAVE BOOK 1(DEFAULT) TO A NAMED FILE. IN CASE OF RE-RUN, CLEAR SHEET1*/
    data _null_;
      file ddeCmds;
      put '[error(false)]';
      put '[save.as("c:\N04\DDEwSASMac\XLS\SASHelpClass")]';
      put '[workbook.select("sheet1")]';
      put %unquote(%bquote('[select("r1c1:r&xlsMaxRow.c&xlsMaxCol.")]'));
      put '[clear(1)]'; *-- VALUES AND FORMULAS (I.E. ALL);
      put '[select("r1c1")]';
    run;

  /* *****
      DDE TRIPLET COMMANDS FOR WRITING SAS DATA, TITLES AND HEADERS TO EXCEL
     ***** */

    /* WRITE BODY */
    filename ddedata dde 
    "excel|[SASHelpClass.xls]sheet1!r&startRow.c1:r&nrows.c&nvars" notab;
    data _null_;
      set class;
      file ddedata;
      put %WriteDStoXLS(dsName=class)
    run;
 
    /* WRITE TITLE */
    filename title dde "excel|[SASHelpClass.xls]sheet1!r1c1:r1c&nvars" notab;
    data _null_;
      file title;
      put "SASHelp.Class Formatted in EXCEL with SAS Macros";
    run;
 
    /* WRITE HEADERS: VARIABLE NAMES AND LABELS */   
    filename HEADERS dde "excel|[SASHelpClass.xls]sheet1!r2c1:r2c&nvars" notab;
    data _null_;
      file HEADERS;
      put %HdrWvblName(dsName=class)
    run;
    filename HEADERS dde "excel|[SASHelpClass.xls]sheet1!r3c1:r3c&nvars" notab;
    data _null_;
      file HEADERS;
      put %HdrWvblLabel(dsName=class)
    run;

  /* *****
     FORMAT EXCEL SPREADSHEET WITH SAS MACROS THAT INVOKE DDE DOUBLETS OR 
      CUSTOMIZE WITH DOUBLETS IN OPEN CODE.
     ***** */

    /* FORMAT TITLE*/ 
    %formatTitle(MaxCol=&nVars, Fontsize=10, Row=1, RowHeight=17)
      
    /* FORMAT HEADERS */    
    %formatHeaders(fontSize=9, Row=2, MaxCol=&nVars)
    %formatHeaders(fontSize=9, Row=3, MaxCol=&nVars)

    /* FORMAT BODY*/
    %formatBody(CmdFileName=ddeCmds, fontSize=9, MinRow=&startRow, Maxrow=&nrows,
                MinCol=1, MaxCol=&nVars)

    /* ALIGN BODY BY CENTERING VALUES BOTH VERTICALLY AND HORIZONTALLY*/
    %alignWorkSheet(maxrow=&nrows, maxCol=&nVars)

    /* BUT LEFT JUSTIFY FIRST NAMES WHILE RETAINING CENTER VERTICAL JUSTIFICATION */
    data _null_;
      file ddeCmds;
      put %unquote(%bquote('[select("r4c1:r&nrows.c1")]'));
      put '[alignment(2)]';
    run;

    /* FORMAT HEIGHT */
    %formatNumber(fmt=%str(#0.0), mincol=c4, maxCol=c4)

    /* FORMAT WEIGHT */
    %formatNumber(fmt=%str(#000.0),mincol=c5, maxCol=c5)

    /* INSERT THIN GRAY LINE UNDER THE HEADERS. */
    %insertLineDivider(row=4, maxCol=&nvars)

    /* HIDE ROW #2 -- VARIABLE NAMES */
    data _null_;
      file ddeCmds;
      put '[row.height(0,"R2",FALSE,1)]';
    run;
    /* TO UNHIDE, GO INTO EXCEL AND SELECT ROWS 1,3 THEN PRESS FORMAT, ROW, UNHIDE */

    /* CONDITIONALLY SAVE ACTIVE DOCUMENT AND CLOSE EXCEL*/
    %saveAndClose(yVsN=&doIt);

  quit;